var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { css, html, LitElement } from 'lit';
import { customElement, property } from 'lit/decorators.js';
import { when } from 'lit/directives/when.js';
let ColorPicker = class ColorPicker extends LitElement {
    handleTypeChanged(e) {
        const type = e.target.selected[0];
        if (type === 'none') {
            this.dispatchEvent(new CustomEvent('color-change', {
                detail: 'none',
                bubbles: true,
                composed: true,
            }));
        }
    }
    handleSolidChanged(e) {
        const value = e.target.color.toString();
        this.dispatchEvent(new CustomEvent('color-change', {
            detail: value,
            bubbles: true,
            composed: true,
        }));
    }
    render() {
        const selected = this.value === 'none' ? 'none' : 'solid';
        return html `
      <h4>Select a color</h4>
      <sp-action-group
        quiet
        compact
        size="m"
        selects="single"
        .selected=${[selected]}
        @change=${this.handleTypeChanged}
      >
        <sp-action-button value="none">
          <sp-tooltip self-managed placement="bottom"> No color </sp-tooltip>
          <sp-swatch nothing slot="icon"> </sp-swatch>
        </sp-action-button>

        <sp-action-button value="solid">
          <sp-tooltip self-managed placement="bottom"> Solid </sp-tooltip>
          <sp-swatch color=${this.value} slot="icon"> </sp-swatch>
        </sp-action-button>

        <sp-action-button value="gradient">
          <sp-tooltip self-managed placement="bottom"> Gradient </sp-tooltip>
          <sp-swatch color=${this.value} slot="icon"> </sp-swatch>
        </sp-action-button>
      </sp-action-group>

      ${when(selected === 'solid', () => html `
          <sp-color-area
            color=${this.value}
            @input=${this.handleSolidChanged}
          ></sp-color-area>
          <sp-color-slider
            color=${this.value}
            @input=${this.handleSolidChanged}
          ></sp-color-slider>
          <div>
            <sp-field-label for="hex" side-aligned="start">Hex</sp-field-label>
            <sp-color-field
              id="hex"
              size="s"
              value=${this.value}
              @input=${this.handleSolidChanged}
            ></sp-color-field>
          </div>
        `)}
    `;
    }
};
ColorPicker.styles = css `
    :host {
      display: flex;
      flex-direction: column;
      gap: 8px;
      padding: 8px;
      width: 300px;
    }

    h4 {
      margin: 0;
    }
  `;
__decorate([
    property()
], ColorPicker.prototype, "value", void 0);
ColorPicker = __decorate([
    customElement('ic-spectrum-color-picker')
], ColorPicker);
export { ColorPicker };
//# sourceMappingURL=color-picker.js.map